Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ProjectMember) predicate.ProjectMember
- func CreatedAt(v time.Time) predicate.ProjectMember
- func CreatedAtEQ(v time.Time) predicate.ProjectMember
- func CreatedAtGT(v time.Time) predicate.ProjectMember
- func CreatedAtGTE(v time.Time) predicate.ProjectMember
- func CreatedAtIn(vs ...time.Time) predicate.ProjectMember
- func CreatedAtLT(v time.Time) predicate.ProjectMember
- func CreatedAtLTE(v time.Time) predicate.ProjectMember
- func CreatedAtNEQ(v time.Time) predicate.ProjectMember
- func CreatedAtNotIn(vs ...time.Time) predicate.ProjectMember
- func HasProject() predicate.ProjectMember
- func HasProjectWith(preds ...predicate.Project) predicate.ProjectMember
- func HasUser() predicate.ProjectMember
- func HasUserWith(preds ...predicate.User) predicate.ProjectMember
- func ID(id int) predicate.ProjectMember
- func IDEQ(id int) predicate.ProjectMember
- func IDGT(id int) predicate.ProjectMember
- func IDGTE(id int) predicate.ProjectMember
- func IDIn(ids ...int) predicate.ProjectMember
- func IDLT(id int) predicate.ProjectMember
- func IDLTE(id int) predicate.ProjectMember
- func IDNEQ(id int) predicate.ProjectMember
- func IDNotIn(ids ...int) predicate.ProjectMember
- func Not(p predicate.ProjectMember) predicate.ProjectMember
- func Or(predicates ...predicate.ProjectMember) predicate.ProjectMember
- func ProjectID(v int) predicate.ProjectMember
- func ProjectIDEQ(v int) predicate.ProjectMember
- func ProjectIDIn(vs ...int) predicate.ProjectMember
- func ProjectIDNEQ(v int) predicate.ProjectMember
- func ProjectIDNotIn(vs ...int) predicate.ProjectMember
- func Role(v string) predicate.ProjectMember
- func RoleContains(v string) predicate.ProjectMember
- func RoleContainsFold(v string) predicate.ProjectMember
- func RoleEQ(v string) predicate.ProjectMember
- func RoleEqualFold(v string) predicate.ProjectMember
- func RoleGT(v string) predicate.ProjectMember
- func RoleGTE(v string) predicate.ProjectMember
- func RoleHasPrefix(v string) predicate.ProjectMember
- func RoleHasSuffix(v string) predicate.ProjectMember
- func RoleIn(vs ...string) predicate.ProjectMember
- func RoleLT(v string) predicate.ProjectMember
- func RoleLTE(v string) predicate.ProjectMember
- func RoleNEQ(v string) predicate.ProjectMember
- func RoleNotIn(vs ...string) predicate.ProjectMember
- func UpdatedAt(v time.Time) predicate.ProjectMember
- func UpdatedAtEQ(v time.Time) predicate.ProjectMember
- func UpdatedAtGT(v time.Time) predicate.ProjectMember
- func UpdatedAtGTE(v time.Time) predicate.ProjectMember
- func UpdatedAtIn(vs ...time.Time) predicate.ProjectMember
- func UpdatedAtLT(v time.Time) predicate.ProjectMember
- func UpdatedAtLTE(v time.Time) predicate.ProjectMember
- func UpdatedAtNEQ(v time.Time) predicate.ProjectMember
- func UpdatedAtNotIn(vs ...time.Time) predicate.ProjectMember
- func UserID(v int) predicate.ProjectMember
- func UserIDEQ(v int) predicate.ProjectMember
- func UserIDIn(vs ...int) predicate.ProjectMember
- func UserIDNEQ(v int) predicate.ProjectMember
- func UserIDNotIn(vs ...int) predicate.ProjectMember
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByProjectID(opts ...sql.OrderTermOption) OrderOption
- func ByRole(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the projectmember type in the database. Label = "project_member" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldProjectID holds the string denoting the project_id field in the database. FieldProjectID = "project_id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldRole holds the string denoting the role field in the database. FieldRole = "role" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeProject holds the string denoting the project edge name in mutations. EdgeProject = "project" // EdgeUser holds the string denoting the user edge name in mutations. EdgeUser = "user" // Table holds the table name of the projectmember in the database. Table = "project_members" // ProjectTable is the table that holds the project relation/edge. ProjectTable = "project_members" // ProjectInverseTable is the table name for the Project entity. // It exists in this package in order to avoid circular dependency with the "project" package. ProjectInverseTable = "projects" // ProjectColumn is the table column denoting the project relation/edge. ProjectColumn = "project_id" // UserTable is the table that holds the user relation/edge. UserTable = "project_members" // UserInverseTable is the table name for the User entity. // It exists in this package in order to avoid circular dependency with the "user" package. UserInverseTable = "users" // UserColumn is the table column denoting the user relation/edge. UserColumn = "user_id" )
Variables ¶
var ( // DefaultRole holds the default value on creation for the "role" field. DefaultRole string // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldProjectID, FieldUserID, FieldRole, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for projectmember fields.
Functions ¶
func And ¶
func And(predicates ...predicate.ProjectMember) predicate.ProjectMember
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.ProjectMember
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.ProjectMember
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.ProjectMember
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.ProjectMember
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.ProjectMember
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.ProjectMember
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.ProjectMember
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.ProjectMember
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.ProjectMember
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasProject ¶
func HasProject() predicate.ProjectMember
HasProject applies the HasEdge predicate on the "project" edge.
func HasProjectWith ¶
func HasProjectWith(preds ...predicate.Project) predicate.ProjectMember
HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).
func HasUser ¶
func HasUser() predicate.ProjectMember
HasUser applies the HasEdge predicate on the "user" edge.
func HasUserWith ¶
func HasUserWith(preds ...predicate.User) predicate.ProjectMember
HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.ProjectMember
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.ProjectMember
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.ProjectMember
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.ProjectMember
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.ProjectMember
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.ProjectMember
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.ProjectMember
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.ProjectMember
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.ProjectMember) predicate.ProjectMember
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ProjectMember) predicate.ProjectMember
Or groups predicates with the OR operator between them.
func ProjectID ¶
func ProjectID(v int) predicate.ProjectMember
ProjectID applies equality check predicate on the "project_id" field. It's identical to ProjectIDEQ.
func ProjectIDEQ ¶
func ProjectIDEQ(v int) predicate.ProjectMember
ProjectIDEQ applies the EQ predicate on the "project_id" field.
func ProjectIDIn ¶
func ProjectIDIn(vs ...int) predicate.ProjectMember
ProjectIDIn applies the In predicate on the "project_id" field.
func ProjectIDNEQ ¶
func ProjectIDNEQ(v int) predicate.ProjectMember
ProjectIDNEQ applies the NEQ predicate on the "project_id" field.
func ProjectIDNotIn ¶
func ProjectIDNotIn(vs ...int) predicate.ProjectMember
ProjectIDNotIn applies the NotIn predicate on the "project_id" field.
func Role ¶
func Role(v string) predicate.ProjectMember
Role applies equality check predicate on the "role" field. It's identical to RoleEQ.
func RoleContains ¶
func RoleContains(v string) predicate.ProjectMember
RoleContains applies the Contains predicate on the "role" field.
func RoleContainsFold ¶
func RoleContainsFold(v string) predicate.ProjectMember
RoleContainsFold applies the ContainsFold predicate on the "role" field.
func RoleEQ ¶
func RoleEQ(v string) predicate.ProjectMember
RoleEQ applies the EQ predicate on the "role" field.
func RoleEqualFold ¶
func RoleEqualFold(v string) predicate.ProjectMember
RoleEqualFold applies the EqualFold predicate on the "role" field.
func RoleGT ¶
func RoleGT(v string) predicate.ProjectMember
RoleGT applies the GT predicate on the "role" field.
func RoleGTE ¶
func RoleGTE(v string) predicate.ProjectMember
RoleGTE applies the GTE predicate on the "role" field.
func RoleHasPrefix ¶
func RoleHasPrefix(v string) predicate.ProjectMember
RoleHasPrefix applies the HasPrefix predicate on the "role" field.
func RoleHasSuffix ¶
func RoleHasSuffix(v string) predicate.ProjectMember
RoleHasSuffix applies the HasSuffix predicate on the "role" field.
func RoleIn ¶
func RoleIn(vs ...string) predicate.ProjectMember
RoleIn applies the In predicate on the "role" field.
func RoleLT ¶
func RoleLT(v string) predicate.ProjectMember
RoleLT applies the LT predicate on the "role" field.
func RoleLTE ¶
func RoleLTE(v string) predicate.ProjectMember
RoleLTE applies the LTE predicate on the "role" field.
func RoleNEQ ¶
func RoleNEQ(v string) predicate.ProjectMember
RoleNEQ applies the NEQ predicate on the "role" field.
func RoleNotIn ¶
func RoleNotIn(vs ...string) predicate.ProjectMember
RoleNotIn applies the NotIn predicate on the "role" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.ProjectMember
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.ProjectMember
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.ProjectMember
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.ProjectMember
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.ProjectMember
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.ProjectMember
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.ProjectMember
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.ProjectMember
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.ProjectMember
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UserID ¶
func UserID(v int) predicate.ProjectMember
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDEQ ¶
func UserIDEQ(v int) predicate.ProjectMember
UserIDEQ applies the EQ predicate on the "user_id" field.
func UserIDIn ¶
func UserIDIn(vs ...int) predicate.ProjectMember
UserIDIn applies the In predicate on the "user_id" field.
func UserIDNEQ ¶
func UserIDNEQ(v int) predicate.ProjectMember
UserIDNEQ applies the NEQ predicate on the "user_id" field.
func UserIDNotIn ¶
func UserIDNotIn(vs ...int) predicate.ProjectMember
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ProjectMember queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByProjectField ¶
func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
ByProjectField orders the results by project field.
func ByProjectID ¶
func ByProjectID(opts ...sql.OrderTermOption) OrderOption
ByProjectID orders the results by the project_id field.
func ByRole ¶
func ByRole(opts ...sql.OrderTermOption) OrderOption
ByRole orders the results by the role field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUserField ¶
func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption
ByUserField orders the results by user field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.