Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.RetentionPolicy) predicate.RetentionPolicy
- func CreatedAt(v time.Time) predicate.RetentionPolicy
- func CreatedAtEQ(v time.Time) predicate.RetentionPolicy
- func CreatedAtGT(v time.Time) predicate.RetentionPolicy
- func CreatedAtGTE(v time.Time) predicate.RetentionPolicy
- func CreatedAtIn(vs ...time.Time) predicate.RetentionPolicy
- func CreatedAtLT(v time.Time) predicate.RetentionPolicy
- func CreatedAtLTE(v time.Time) predicate.RetentionPolicy
- func CreatedAtNEQ(v time.Time) predicate.RetentionPolicy
- func CreatedAtNotIn(vs ...time.Time) predicate.RetentionPolicy
- func Description(v string) predicate.RetentionPolicy
- func DescriptionContains(v string) predicate.RetentionPolicy
- func DescriptionContainsFold(v string) predicate.RetentionPolicy
- func DescriptionEQ(v string) predicate.RetentionPolicy
- func DescriptionEqualFold(v string) predicate.RetentionPolicy
- func DescriptionGT(v string) predicate.RetentionPolicy
- func DescriptionGTE(v string) predicate.RetentionPolicy
- func DescriptionHasPrefix(v string) predicate.RetentionPolicy
- func DescriptionHasSuffix(v string) predicate.RetentionPolicy
- func DescriptionIn(vs ...string) predicate.RetentionPolicy
- func DescriptionIsNil() predicate.RetentionPolicy
- func DescriptionLT(v string) predicate.RetentionPolicy
- func DescriptionLTE(v string) predicate.RetentionPolicy
- func DescriptionNEQ(v string) predicate.RetentionPolicy
- func DescriptionNotIn(vs ...string) predicate.RetentionPolicy
- func DescriptionNotNil() predicate.RetentionPolicy
- func DurationDays(v int) predicate.RetentionPolicy
- func DurationDaysEQ(v int) predicate.RetentionPolicy
- func DurationDaysGT(v int) predicate.RetentionPolicy
- func DurationDaysGTE(v int) predicate.RetentionPolicy
- func DurationDaysIn(vs ...int) predicate.RetentionPolicy
- func DurationDaysLT(v int) predicate.RetentionPolicy
- func DurationDaysLTE(v int) predicate.RetentionPolicy
- func DurationDaysNEQ(v int) predicate.RetentionPolicy
- func DurationDaysNotIn(vs ...int) predicate.RetentionPolicy
- func HasProject() predicate.RetentionPolicy
- func HasProjectWith(preds ...predicate.Project) predicate.RetentionPolicy
- func ID(id int) predicate.RetentionPolicy
- func IDEQ(id int) predicate.RetentionPolicy
- func IDGT(id int) predicate.RetentionPolicy
- func IDGTE(id int) predicate.RetentionPolicy
- func IDIn(ids ...int) predicate.RetentionPolicy
- func IDLT(id int) predicate.RetentionPolicy
- func IDLTE(id int) predicate.RetentionPolicy
- func IDNEQ(id int) predicate.RetentionPolicy
- func IDNotIn(ids ...int) predicate.RetentionPolicy
- func IsActive(v bool) predicate.RetentionPolicy
- func IsActiveEQ(v bool) predicate.RetentionPolicy
- func IsActiveNEQ(v bool) predicate.RetentionPolicy
- func Name(v string) predicate.RetentionPolicy
- func NameContains(v string) predicate.RetentionPolicy
- func NameContainsFold(v string) predicate.RetentionPolicy
- func NameEQ(v string) predicate.RetentionPolicy
- func NameEqualFold(v string) predicate.RetentionPolicy
- func NameGT(v string) predicate.RetentionPolicy
- func NameGTE(v string) predicate.RetentionPolicy
- func NameHasPrefix(v string) predicate.RetentionPolicy
- func NameHasSuffix(v string) predicate.RetentionPolicy
- func NameIn(vs ...string) predicate.RetentionPolicy
- func NameLT(v string) predicate.RetentionPolicy
- func NameLTE(v string) predicate.RetentionPolicy
- func NameNEQ(v string) predicate.RetentionPolicy
- func NameNotIn(vs ...string) predicate.RetentionPolicy
- func Not(p predicate.RetentionPolicy) predicate.RetentionPolicy
- func Or(predicates ...predicate.RetentionPolicy) predicate.RetentionPolicy
- func UpdatedAt(v time.Time) predicate.RetentionPolicy
- func UpdatedAtEQ(v time.Time) predicate.RetentionPolicy
- func UpdatedAtGT(v time.Time) predicate.RetentionPolicy
- func UpdatedAtGTE(v time.Time) predicate.RetentionPolicy
- func UpdatedAtIn(vs ...time.Time) predicate.RetentionPolicy
- func UpdatedAtLT(v time.Time) predicate.RetentionPolicy
- func UpdatedAtLTE(v time.Time) predicate.RetentionPolicy
- func UpdatedAtNEQ(v time.Time) predicate.RetentionPolicy
- func UpdatedAtNotIn(vs ...time.Time) predicate.RetentionPolicy
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDescription(opts ...sql.OrderTermOption) OrderOption
- func ByDurationDays(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIsActive(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the retentionpolicy type in the database. Label = "retention_policy" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldDurationDays holds the string denoting the duration_days field in the database. FieldDurationDays = "duration_days" // FieldDescription holds the string denoting the description field in the database. FieldDescription = "description" // FieldIsActive holds the string denoting the is_active field in the database. FieldIsActive = "is_active" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeProject holds the string denoting the project edge name in mutations. EdgeProject = "project" // Table holds the table name of the retentionpolicy in the database. Table = "retention_policies" // ProjectTable is the table that holds the project relation/edge. ProjectTable = "retention_policies" // ProjectInverseTable is the table name for the Project entity. // It exists in this package in order to avoid circular dependency with the "project" package. ProjectInverseTable = "projects" // ProjectColumn is the table column denoting the project relation/edge. ProjectColumn = "project_retention_policies" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultDurationDays holds the default value on creation for the "duration_days" field. DefaultDurationDays int // DurationDaysValidator is a validator for the "duration_days" field. It is called by the builders before save. DurationDaysValidator func(int) error // DefaultIsActive holds the default value on creation for the "is_active" field. DefaultIsActive bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time )
var Columns = []string{ FieldID, FieldName, FieldDurationDays, FieldDescription, FieldIsActive, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for retentionpolicy fields.
var ForeignKeys = []string{
"project_retention_policies",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "retention_policies" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.RetentionPolicy) predicate.RetentionPolicy
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.RetentionPolicy
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.RetentionPolicy
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.RetentionPolicy
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.RetentionPolicy
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.RetentionPolicy
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.RetentionPolicy
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.RetentionPolicy
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.RetentionPolicy
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.RetentionPolicy
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Description ¶
func Description(v string) predicate.RetentionPolicy
Description applies equality check predicate on the "description" field. It's identical to DescriptionEQ.
func DescriptionContains ¶
func DescriptionContains(v string) predicate.RetentionPolicy
DescriptionContains applies the Contains predicate on the "description" field.
func DescriptionContainsFold ¶
func DescriptionContainsFold(v string) predicate.RetentionPolicy
DescriptionContainsFold applies the ContainsFold predicate on the "description" field.
func DescriptionEQ ¶
func DescriptionEQ(v string) predicate.RetentionPolicy
DescriptionEQ applies the EQ predicate on the "description" field.
func DescriptionEqualFold ¶
func DescriptionEqualFold(v string) predicate.RetentionPolicy
DescriptionEqualFold applies the EqualFold predicate on the "description" field.
func DescriptionGT ¶
func DescriptionGT(v string) predicate.RetentionPolicy
DescriptionGT applies the GT predicate on the "description" field.
func DescriptionGTE ¶
func DescriptionGTE(v string) predicate.RetentionPolicy
DescriptionGTE applies the GTE predicate on the "description" field.
func DescriptionHasPrefix ¶
func DescriptionHasPrefix(v string) predicate.RetentionPolicy
DescriptionHasPrefix applies the HasPrefix predicate on the "description" field.
func DescriptionHasSuffix ¶
func DescriptionHasSuffix(v string) predicate.RetentionPolicy
DescriptionHasSuffix applies the HasSuffix predicate on the "description" field.
func DescriptionIn ¶
func DescriptionIn(vs ...string) predicate.RetentionPolicy
DescriptionIn applies the In predicate on the "description" field.
func DescriptionIsNil ¶
func DescriptionIsNil() predicate.RetentionPolicy
DescriptionIsNil applies the IsNil predicate on the "description" field.
func DescriptionLT ¶
func DescriptionLT(v string) predicate.RetentionPolicy
DescriptionLT applies the LT predicate on the "description" field.
func DescriptionLTE ¶
func DescriptionLTE(v string) predicate.RetentionPolicy
DescriptionLTE applies the LTE predicate on the "description" field.
func DescriptionNEQ ¶
func DescriptionNEQ(v string) predicate.RetentionPolicy
DescriptionNEQ applies the NEQ predicate on the "description" field.
func DescriptionNotIn ¶
func DescriptionNotIn(vs ...string) predicate.RetentionPolicy
DescriptionNotIn applies the NotIn predicate on the "description" field.
func DescriptionNotNil ¶
func DescriptionNotNil() predicate.RetentionPolicy
DescriptionNotNil applies the NotNil predicate on the "description" field.
func DurationDays ¶
func DurationDays(v int) predicate.RetentionPolicy
DurationDays applies equality check predicate on the "duration_days" field. It's identical to DurationDaysEQ.
func DurationDaysEQ ¶
func DurationDaysEQ(v int) predicate.RetentionPolicy
DurationDaysEQ applies the EQ predicate on the "duration_days" field.
func DurationDaysGT ¶
func DurationDaysGT(v int) predicate.RetentionPolicy
DurationDaysGT applies the GT predicate on the "duration_days" field.
func DurationDaysGTE ¶
func DurationDaysGTE(v int) predicate.RetentionPolicy
DurationDaysGTE applies the GTE predicate on the "duration_days" field.
func DurationDaysIn ¶
func DurationDaysIn(vs ...int) predicate.RetentionPolicy
DurationDaysIn applies the In predicate on the "duration_days" field.
func DurationDaysLT ¶
func DurationDaysLT(v int) predicate.RetentionPolicy
DurationDaysLT applies the LT predicate on the "duration_days" field.
func DurationDaysLTE ¶
func DurationDaysLTE(v int) predicate.RetentionPolicy
DurationDaysLTE applies the LTE predicate on the "duration_days" field.
func DurationDaysNEQ ¶
func DurationDaysNEQ(v int) predicate.RetentionPolicy
DurationDaysNEQ applies the NEQ predicate on the "duration_days" field.
func DurationDaysNotIn ¶
func DurationDaysNotIn(vs ...int) predicate.RetentionPolicy
DurationDaysNotIn applies the NotIn predicate on the "duration_days" field.
func HasProject ¶
func HasProject() predicate.RetentionPolicy
HasProject applies the HasEdge predicate on the "project" edge.
func HasProjectWith ¶
func HasProjectWith(preds ...predicate.Project) predicate.RetentionPolicy
HasProjectWith applies the HasEdge predicate on the "project" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id int) predicate.RetentionPolicy
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int) predicate.RetentionPolicy
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int) predicate.RetentionPolicy
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int) predicate.RetentionPolicy
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int) predicate.RetentionPolicy
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int) predicate.RetentionPolicy
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int) predicate.RetentionPolicy
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int) predicate.RetentionPolicy
IDNotIn applies the NotIn predicate on the ID field.
func IsActive ¶
func IsActive(v bool) predicate.RetentionPolicy
IsActive applies equality check predicate on the "is_active" field. It's identical to IsActiveEQ.
func IsActiveEQ ¶
func IsActiveEQ(v bool) predicate.RetentionPolicy
IsActiveEQ applies the EQ predicate on the "is_active" field.
func IsActiveNEQ ¶
func IsActiveNEQ(v bool) predicate.RetentionPolicy
IsActiveNEQ applies the NEQ predicate on the "is_active" field.
func Name ¶
func Name(v string) predicate.RetentionPolicy
Name applies equality check predicate on the "name" field. It's identical to NameEQ.
func NameContains ¶
func NameContains(v string) predicate.RetentionPolicy
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
func NameContainsFold(v string) predicate.RetentionPolicy
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEQ ¶
func NameEQ(v string) predicate.RetentionPolicy
NameEQ applies the EQ predicate on the "name" field.
func NameEqualFold ¶
func NameEqualFold(v string) predicate.RetentionPolicy
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameGT ¶
func NameGT(v string) predicate.RetentionPolicy
NameGT applies the GT predicate on the "name" field.
func NameGTE ¶
func NameGTE(v string) predicate.RetentionPolicy
NameGTE applies the GTE predicate on the "name" field.
func NameHasPrefix ¶
func NameHasPrefix(v string) predicate.RetentionPolicy
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
func NameHasSuffix(v string) predicate.RetentionPolicy
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func NameIn ¶
func NameIn(vs ...string) predicate.RetentionPolicy
NameIn applies the In predicate on the "name" field.
func NameLT ¶
func NameLT(v string) predicate.RetentionPolicy
NameLT applies the LT predicate on the "name" field.
func NameLTE ¶
func NameLTE(v string) predicate.RetentionPolicy
NameLTE applies the LTE predicate on the "name" field.
func NameNEQ ¶
func NameNEQ(v string) predicate.RetentionPolicy
NameNEQ applies the NEQ predicate on the "name" field.
func NameNotIn ¶
func NameNotIn(vs ...string) predicate.RetentionPolicy
NameNotIn applies the NotIn predicate on the "name" field.
func Not ¶
func Not(p predicate.RetentionPolicy) predicate.RetentionPolicy
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.RetentionPolicy) predicate.RetentionPolicy
Or groups predicates with the OR operator between them.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.RetentionPolicy
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.RetentionPolicy
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.RetentionPolicy
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.RetentionPolicy
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.RetentionPolicy
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.RetentionPolicy
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.RetentionPolicy
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.RetentionPolicy
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.RetentionPolicy
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the RetentionPolicy queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDescription ¶
func ByDescription(opts ...sql.OrderTermOption) OrderOption
ByDescription orders the results by the description field.
func ByDurationDays ¶
func ByDurationDays(opts ...sql.OrderTermOption) OrderOption
ByDurationDays orders the results by the duration_days field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIsActive ¶
func ByIsActive(opts ...sql.OrderTermOption) OrderOption
ByIsActive orders the results by the is_active field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByProjectField ¶
func ByProjectField(field string, opts ...sql.OrderTermOption) OrderOption
ByProjectField orders the results by project field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.